@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.4.0";
+our $VERSION = "1.5.0";
 
 sub challenge_google {
     my ($ua,$result) = @_;
@@ -88,6 +88,10 @@ sub challenge_crawlers {
             return 1;
         }
     }
+    elsif (index($ua, "BingPreview") > -1) {
+        update_map($result, dataset("BingPreview"));
+        return 1;
+    }
     elsif (index($ua, "Baidu") > -1) {
         if (index($ua, "compatible; Baiduspider") > -1 || index($ua, "Baiduspider+") > -1 || index($ua, "Baiduspider-image+") > -1) {
             update_map($result, dataset("Baiduspider"));
